==> purescript-0.11.5-19-x86_64.pkg.tar.xz: usr/share/haskell/register/purescript.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: purescript
version: 0.11.5
id: purescript-0.11.5-GSbpj2HrH1jE4iAZlndlxC
key: purescript-0.11.5-GSbpj2HrH1jE4iAZlndlxC
license: BSD3
copyright: (c) 2013-17 Phil Freeman, (c) 2014-17 Gary Burgess
maintainer: Phil Freeman <paf31@cantab.net>
stability: experimental
homepage: http://www.purescript.org/
synopsis: PureScript Programming Language Compiler
description:
    A small strongly, statically typed programming language with expressive types, inspired by Haskell and compiling to JavaScript.
category: Language
author: Phil Freeman <paf31@cantab.net>, Gary Burgess <gary.burgess@gmail.com>, Hardy Jones <jones3.hardy@gmail.com>, Harry Garrood <harry@garrood.me>, Christoph Hegemann <christoph.hegemann1337@gmail.com>
exposed: True
exposed-modules:
    Control.Monad.Logger Control.Monad.Supply
    Control.Monad.Supply.Class Language.PureScript
    Language.PureScript.AST Language.PureScript.AST.Binders
    Language.PureScript.AST.Declarations
    Language.PureScript.AST.Exported Language.PureScript.AST.Literals
    Language.PureScript.AST.Operators Language.PureScript.AST.SourcePos
    Language.PureScript.AST.Traversals Language.PureScript.Bundle
    Language.PureScript.CodeGen Language.PureScript.CodeGen.JS
    Language.PureScript.CodeGen.JS.Common
    Language.PureScript.CodeGen.JS.Printer Language.PureScript.Comments
    Language.PureScript.Constants Language.PureScript.CoreFn
    Language.PureScript.CoreFn.Ann Language.PureScript.CoreFn.Binders
    Language.PureScript.CoreFn.Desugar Language.PureScript.CoreFn.Expr
    Language.PureScript.CoreFn.Meta Language.PureScript.CoreFn.Module
    Language.PureScript.CoreFn.ToJSON
    Language.PureScript.CoreFn.Traversals Language.PureScript.CoreImp
    Language.PureScript.CoreImp.AST
    Language.PureScript.CoreImp.Optimizer
    Language.PureScript.CoreImp.Optimizer.Blocks
    Language.PureScript.CoreImp.Optimizer.Common
    Language.PureScript.CoreImp.Optimizer.Inliner
    Language.PureScript.CoreImp.Optimizer.MagicDo
    Language.PureScript.CoreImp.Optimizer.TCO
    Language.PureScript.CoreImp.Optimizer.Unused
    Language.PureScript.Crash Language.PureScript.Docs
    Language.PureScript.Docs.AsHtml Language.PureScript.Docs.AsMarkdown
    Language.PureScript.Docs.Convert
    Language.PureScript.Docs.Convert.ReExports
    Language.PureScript.Docs.Convert.Single
    Language.PureScript.Docs.ParseInPackage
    Language.PureScript.Docs.Prim Language.PureScript.Docs.Render
    Language.PureScript.Docs.RenderedCode
    Language.PureScript.Docs.RenderedCode.RenderKind
    Language.PureScript.Docs.RenderedCode.RenderType
    Language.PureScript.Docs.RenderedCode.Types
    Language.PureScript.Docs.Types
    Language.PureScript.Docs.Utils.MonoidExtras
    Language.PureScript.Environment Language.PureScript.Errors
    Language.PureScript.Errors.JSON Language.PureScript.Externs
    Language.PureScript.Ide Language.PureScript.Ide.CaseSplit
    Language.PureScript.Ide.Command Language.PureScript.Ide.Completion
    Language.PureScript.Ide.Error Language.PureScript.Ide.Externs
    Language.PureScript.Ide.Filter Language.PureScript.Ide.Imports
    Language.PureScript.Ide.Logging Language.PureScript.Ide.Matcher
    Language.PureScript.Ide.Pursuit Language.PureScript.Ide.Rebuild
    Language.PureScript.Ide.Reexports
    Language.PureScript.Ide.SourceFile Language.PureScript.Ide.State
    Language.PureScript.Ide.Types Language.PureScript.Ide.Util
    Language.PureScript.Ide.Watcher Language.PureScript.Interactive
    Language.PureScript.Interactive.Completion
    Language.PureScript.Interactive.Directive
    Language.PureScript.Interactive.IO
    Language.PureScript.Interactive.Message
    Language.PureScript.Interactive.Module
    Language.PureScript.Interactive.Parser
    Language.PureScript.Interactive.Printer
    Language.PureScript.Interactive.Types Language.PureScript.Kinds
    Language.PureScript.Label Language.PureScript.Linter
    Language.PureScript.Linter.Exhaustive
    Language.PureScript.Linter.Imports Language.PureScript.Make
    Language.PureScript.ModuleDependencies Language.PureScript.Names
    Language.PureScript.Options Language.PureScript.Parser
    Language.PureScript.Parser.Common
    Language.PureScript.Parser.Declarations
    Language.PureScript.Parser.Kinds Language.PureScript.Parser.Lexer
    Language.PureScript.Parser.State Language.PureScript.Parser.Types
    Language.PureScript.Pretty Language.PureScript.Pretty.Common
    Language.PureScript.Pretty.Kinds Language.PureScript.Pretty.Types
    Language.PureScript.Pretty.Values Language.PureScript.PSString
    Language.PureScript.Publish
    Language.PureScript.Publish.BoxesHelpers
    Language.PureScript.Publish.ErrorsWarnings
    Language.PureScript.Publish.Utils Language.PureScript.Renamer
    Language.PureScript.Sugar Language.PureScript.Sugar.BindingGroups
    Language.PureScript.Sugar.CaseDeclarations
    Language.PureScript.Sugar.DoNotation
    Language.PureScript.Sugar.LetPattern
    Language.PureScript.Sugar.Names
    Language.PureScript.Sugar.Names.Common
    Language.PureScript.Sugar.Names.Env
    Language.PureScript.Sugar.Names.Exports
    Language.PureScript.Sugar.Names.Imports
    Language.PureScript.Sugar.ObjectWildcards
    Language.PureScript.Sugar.Operators
    Language.PureScript.Sugar.Operators.Binders
    Language.PureScript.Sugar.Operators.Common
    Language.PureScript.Sugar.Operators.Expr
    Language.PureScript.Sugar.Operators.Types
    Language.PureScript.Sugar.TypeClasses
    Language.PureScript.Sugar.TypeClasses.Deriving
    Language.PureScript.Sugar.TypeDeclarations
    Language.PureScript.Traversals Language.PureScript.TypeChecker
    Language.PureScript.TypeChecker.Entailment
    Language.PureScript.TypeChecker.Kinds
    Language.PureScript.TypeChecker.Monad
    Language.PureScript.TypeChecker.Skolems
    Language.PureScript.TypeChecker.Subsumption
    Language.PureScript.TypeChecker.Synonyms
    Language.PureScript.TypeChecker.Types
    Language.PureScript.TypeChecker.TypeSearch
    Language.PureScript.TypeChecker.Unify
    Language.PureScript.TypeClassDictionaries Language.PureScript.Types
    System.IO.UTF8
hidden-modules: Paths_purescript
abi: 84c26da698a35dd956deb4cefb264453
trusted: False
import-dirs: /usr/lib/ghc-8.0.2/site-local/purescript-0.11.5
library-dirs: /usr/lib/ghc-8.0.2/site-local/purescript-0.11.5
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/purescript
hs-libraries: HSpurescript-0.11.5-GSbpj2HrH1jE4iAZlndlxC
depends:
    Glob-0.7.14-6595dJ7BxW3Kn5l6eVpWRf
    aeson-1.1.2.0-H9d5B7Pgw9tIbOpl8Ot3sY
    aeson-better-errors-0.9.1.0-4GrMtDffwez5VRbOBd36mX
    ansi-terminal-0.6.3.1-59sjf9WqHYuFAo9gQw9Bhp base-4.9.1.0
    base-compat-0.9.3-KeJp8zYMpcS9WibvTcxU22
    blaze-html-0.8.1.3-EHw0sCLFL6JKZx2lFkE5O8
    bower-json-1.0.0.1-4UFBtxc7AIy79KshSUXOMA
    boxes-0.1.4-8r7hgbHhiwZ9TYlQbo7ovB bytestring-0.10.8.1
    cheapskate-0.1.0.5-bu3fI1ymE3ESRe2qHXY7
    clock-0.7.2-6ZjQ4liQAtMEQ8sxJKD0xY containers-0.5.7.1
    data-ordlist-0.4.7.0-D6ij7F9rr5a9kcQtGict4V deepseq-1.4.2.0
    directory-1.3.0.0 dlist-0.8.0.2-6Wnps4GD7EFnRucVzXIFD
    edit-distance-0.2.2.1-6t5gSPdZR9l59S7jfGb06u filepath-1.4.1.1
    fsnotify-0.2.1-5DjHEI2ebLX5pCQ15CBX6S haskeline-0.7.3.0
    http-client-0.5.7.0-8CqgjLtDELe98Oo6kiK06v
    http-types-0.9.1-IqlxYYwrFhNBj6J7ATsByJ
    language-javascript-0.6.0.10-9oFnD4PXVWdGp1AHGtZBn7
    lens-4.15.3-60anFPcl0sa4AbScjQzShN
    lifted-base-0.2.3.11-5HGJGSXUc2GCx17d867zNZ
    monad-control-1.0.2.1-CGbUZWvNENX5nExoNw6Fw5
    monad-logger-0.3.24-twqLH7Pylj8T2KrVhTzj6
    mtl-2.2.1-BLKBelFsPB3BoFeSWSOYj6
    parallel-3.2.1.1-KQJHWCcq2Ka569Stb10nhx
    parsec-3.1.11-1CA7c0vSU7tJHGhveOjoXR
    pattern-arrows-0.0.2-DvsXxWO2TaB4KdokUxVGav
    pipes-4.3.4-D1DtZU2vcOAFU5xDTsmykH
    pipes-http-1.0.5-14wAEahUaZq1troZEtPSwX process-1.4.3.0
    protolude-0.1.10-K9ygvj85l3B6GBr8vAR1b9
    regex-tdfa-1.2.2-JFeutuWiS2vGBM4qXQlqio
    safe-0.3.15-2Yd45VWFfdcKqKyispOifY
    scientific-0.3.4.15-Is44CvKqXBF5ugVqyS94hI
    semigroups-0.18.3-5xL9BgkWQsCGwo6YahyMCM
    sourcemap-0.1.6-Dfm37E02oVwEbdCXOZwNnH
    spdx-0.2.2.0-6sTWw4uv4IO3OJf6P0KC10
    split-0.2.3.2-CJl40zTyCIV16Pr60nb7CT
    stm-2.4.4.1-iSYwp3RMY11sHCifJ3gtR
    stringsearch-0.3.6.6-8anNeXolBRk4a9DV14i2Be
    syb-0.6-IcoSwlPi2Nx4zSqMmorFPS text-1.2.2.2-3ENqlljngKa6xj1Go2fVWq
    time-1.6.0.1 transformers-0.5.2.0
    transformers-base-0.4.4-H3XecnBtTa65CX4xecxCVH
    transformers-compat-0.5.1.4-IuFogs8HAVUJBWVNMhtssu
    unordered-containers-0.2.8.0-1tqMF698WJE3INvmpuzQZc
    utf8-string-1.0.1.1-1DpjxLeTvGg7ttZZojxJR5
    vector-0.12.0.1-692PQMDMB6pIQ1uGwefDcQ
haddock-interfaces: /usr/share/doc/purescript/html/purescript.haddock
haddock-html: /usr/share/doc/purescript/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> purescript-0.11.6-4-x86_64.pkg.tar.xz: usr/share/haskell/register/purescript.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: purescript
version: 0.11.6
id: purescript-0.11.6-FH7waWkD6GQKRwiG3siRFE
key: purescript-0.11.6-FH7waWkD6GQKRwiG3siRFE
license: BSD3
copyright: (c) 2013-17 Phil Freeman, (c) 2014-17 Gary Burgess
maintainer: Phil Freeman <paf31@cantab.net>
stability: experimental
homepage: http://www.purescript.org/
synopsis: PureScript Programming Language Compiler
description:
    A small strongly, statically typed programming language with expressive types, inspired by Haskell and compiling to JavaScript.
category: Language
author: Phil Freeman <paf31@cantab.net>, Gary Burgess <gary.burgess@gmail.com>, Hardy Jones <jones3.hardy@gmail.com>, Harry Garrood <harry@garrood.me>, Christoph Hegemann <christoph.hegemann1337@gmail.com>
exposed: True
exposed-modules:
    Control.Monad.Logger Control.Monad.Supply
    Control.Monad.Supply.Class Language.PureScript
    Language.PureScript.AST Language.PureScript.AST.Binders
    Language.PureScript.AST.Declarations
    Language.PureScript.AST.Exported Language.PureScript.AST.Literals
    Language.PureScript.AST.Operators Language.PureScript.AST.SourcePos
    Language.PureScript.AST.Traversals Language.PureScript.Bundle
    Language.PureScript.CodeGen Language.PureScript.CodeGen.JS
    Language.PureScript.CodeGen.JS.Common
    Language.PureScript.CodeGen.JS.Printer Language.PureScript.Comments
    Language.PureScript.Constants Language.PureScript.CoreFn
    Language.PureScript.CoreFn.Ann Language.PureScript.CoreFn.Binders
    Language.PureScript.CoreFn.Desugar Language.PureScript.CoreFn.Expr
    Language.PureScript.CoreFn.Meta Language.PureScript.CoreFn.Module
    Language.PureScript.CoreFn.ToJSON
    Language.PureScript.CoreFn.Traversals Language.PureScript.CoreImp
    Language.PureScript.CoreImp.AST
    Language.PureScript.CoreImp.Optimizer
    Language.PureScript.CoreImp.Optimizer.Blocks
    Language.PureScript.CoreImp.Optimizer.Common
    Language.PureScript.CoreImp.Optimizer.Inliner
    Language.PureScript.CoreImp.Optimizer.MagicDo
    Language.PureScript.CoreImp.Optimizer.TCO
    Language.PureScript.CoreImp.Optimizer.Unused
    Language.PureScript.Crash Language.PureScript.Docs
    Language.PureScript.Docs.AsHtml Language.PureScript.Docs.AsMarkdown
    Language.PureScript.Docs.Convert
    Language.PureScript.Docs.Convert.ReExports
    Language.PureScript.Docs.Convert.Single
    Language.PureScript.Docs.ParseInPackage
    Language.PureScript.Docs.Prim Language.PureScript.Docs.Render
    Language.PureScript.Docs.RenderedCode
    Language.PureScript.Docs.RenderedCode.RenderKind
    Language.PureScript.Docs.RenderedCode.RenderType
    Language.PureScript.Docs.RenderedCode.Types
    Language.PureScript.Docs.Types
    Language.PureScript.Docs.Utils.MonoidExtras
    Language.PureScript.Environment Language.PureScript.Errors
    Language.PureScript.Errors.JSON Language.PureScript.Externs
    Language.PureScript.Ide Language.PureScript.Ide.CaseSplit
    Language.PureScript.Ide.Command Language.PureScript.Ide.Completion
    Language.PureScript.Ide.Error Language.PureScript.Ide.Externs
    Language.PureScript.Ide.Filter
    Language.PureScript.Ide.Filter.Declaration
    Language.PureScript.Ide.Imports Language.PureScript.Ide.Logging
    Language.PureScript.Ide.Matcher Language.PureScript.Ide.Prim
    Language.PureScript.Ide.Pursuit Language.PureScript.Ide.Rebuild
    Language.PureScript.Ide.Reexports
    Language.PureScript.Ide.SourceFile Language.PureScript.Ide.State
    Language.PureScript.Ide.Types Language.PureScript.Ide.Util
    Language.PureScript.Ide.Watcher Language.PureScript.Interactive
    Language.PureScript.Interactive.Completion
    Language.PureScript.Interactive.Directive
    Language.PureScript.Interactive.IO
    Language.PureScript.Interactive.Message
    Language.PureScript.Interactive.Module
    Language.PureScript.Interactive.Parser
    Language.PureScript.Interactive.Printer
    Language.PureScript.Interactive.Types Language.PureScript.Kinds
    Language.PureScript.Label Language.PureScript.Linter
    Language.PureScript.Linter.Exhaustive
    Language.PureScript.Linter.Imports Language.PureScript.Make
    Language.PureScript.ModuleDependencies Language.PureScript.Names
    Language.PureScript.Options Language.PureScript.Parser
    Language.PureScript.Parser.Common
    Language.PureScript.Parser.Declarations
    Language.PureScript.Parser.Kinds Language.PureScript.Parser.Lexer
    Language.PureScript.Parser.State Language.PureScript.Parser.Types
    Language.PureScript.Pretty Language.PureScript.Pretty.Common
    Language.PureScript.Pretty.Kinds Language.PureScript.Pretty.Types
    Language.PureScript.Pretty.Values Language.PureScript.PSString
    Language.PureScript.Publish
    Language.PureScript.Publish.BoxesHelpers
    Language.PureScript.Publish.ErrorsWarnings
    Language.PureScript.Publish.Utils Language.PureScript.Renamer
    Language.PureScript.Sugar Language.PureScript.Sugar.BindingGroups
    Language.PureScript.Sugar.CaseDeclarations
    Language.PureScript.Sugar.DoNotation
    Language.PureScript.Sugar.LetPattern
    Language.PureScript.Sugar.Names
    Language.PureScript.Sugar.Names.Common
    Language.PureScript.Sugar.Names.Env
    Language.PureScript.Sugar.Names.Exports
    Language.PureScript.Sugar.Names.Imports
    Language.PureScript.Sugar.ObjectWildcards
    Language.PureScript.Sugar.Operators
    Language.PureScript.Sugar.Operators.Binders
    Language.PureScript.Sugar.Operators.Common
    Language.PureScript.Sugar.Operators.Expr
    Language.PureScript.Sugar.Operators.Types
    Language.PureScript.Sugar.TypeClasses
    Language.PureScript.Sugar.TypeClasses.Deriving
    Language.PureScript.Sugar.TypeDeclarations
    Language.PureScript.Traversals Language.PureScript.TypeChecker
    Language.PureScript.TypeChecker.Entailment
    Language.PureScript.TypeChecker.Kinds
    Language.PureScript.TypeChecker.Monad
    Language.PureScript.TypeChecker.Skolems
    Language.PureScript.TypeChecker.Subsumption
    Language.PureScript.TypeChecker.Synonyms
    Language.PureScript.TypeChecker.Types
    Language.PureScript.TypeChecker.TypeSearch
    Language.PureScript.TypeChecker.Unify
    Language.PureScript.TypeClassDictionaries Language.PureScript.Types
    System.IO.UTF8
hidden-modules: Paths_purescript
abi: af85df4cbf7529f9adf776878fcec202
trusted: False
import-dirs: /usr/lib/ghc-8.0.2/site-local/purescript-0.11.6
library-dirs: /usr/lib/ghc-8.0.2/site-local/purescript-0.11.6
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/purescript
hs-libraries: HSpurescript-0.11.6-FH7waWkD6GQKRwiG3siRFE
depends:
    Glob-0.7.14-9UgIHX1kslJ9qchuvR7jbv
    aeson-1.1.2.0-3Yc3xmkAyKHC7Vn5OXDFOk
    aeson-better-errors-0.9.1.0-AD1OmUBuckg6rbFXPfyMts
    ansi-terminal-0.6.3.1-59sjf9WqHYuFAo9gQw9Bhp base-4.9.1.0
    base-compat-0.9.3-KeJp8zYMpcS9WibvTcxU22
    blaze-html-0.8.1.3-EHw0sCLFL6JKZx2lFkE5O8
    bower-json-1.0.0.1-DJFqKOhkiv529tpPKX97bg
    boxes-0.1.4-8r7hgbHhiwZ9TYlQbo7ovB bytestring-0.10.8.1
    cheapskate-0.1.0.5-KV6DmPwqe36ESre8KtKsqW
    clock-0.7.2-6ZjQ4liQAtMEQ8sxJKD0xY containers-0.5.7.1
    data-ordlist-0.4.7.0-D6ij7F9rr5a9kcQtGict4V deepseq-1.4.2.0
    directory-1.3.0.0 dlist-0.8.0.3-BHFBNaw8k6n9WiaUNzoXpk
    edit-distance-0.2.2.1-6t5gSPdZR9l59S7jfGb06u filepath-1.4.1.1
    fsnotify-0.2.1-5DjHEI2ebLX5pCQ15CBX6S haskeline-0.7.3.0
    http-client-0.5.7.0-8CqgjLtDELe98Oo6kiK06v
    http-types-0.9.1-IqlxYYwrFhNBj6J7ATsByJ
    language-javascript-0.6.0.10-9oFnD4PXVWdGp1AHGtZBn7
    lens-4.15.3-60anFPcl0sa4AbScjQzShN
    lifted-base-0.2.3.11-5HGJGSXUc2GCx17d867zNZ
    monad-control-1.0.2.1-CGbUZWvNENX5nExoNw6Fw5
    monad-logger-0.3.24-3qXfgqb4hYc9kkpULw6T6e
    mtl-2.2.1-BLKBelFsPB3BoFeSWSOYj6
    parallel-3.2.1.1-KQJHWCcq2Ka569Stb10nhx
    parsec-3.1.11-1CA7c0vSU7tJHGhveOjoXR
    pattern-arrows-0.0.2-DvsXxWO2TaB4KdokUxVGav
    pipes-4.3.4-D1DtZU2vcOAFU5xDTsmykH
    pipes-http-1.0.5-8Gyu2fAqrE0HlWoEdW12Rs process-1.4.3.0
    protolude-0.1.10-K9ygvj85l3B6GBr8vAR1b9
    regex-tdfa-1.2.2-JFeutuWiS2vGBM4qXQlqio
    safe-0.3.15-2Yd45VWFfdcKqKyispOifY
    scientific-0.3.5.1-3aJEdQvcyho88FhIoGrzGS
    semigroups-0.18.3-5xL9BgkWQsCGwo6YahyMCM
    sourcemap-0.1.6-vafkd9nKYzIiih8K255He
    spdx-0.2.2.0-6sTWw4uv4IO3OJf6P0KC10
    split-0.2.3.2-CJl40zTyCIV16Pr60nb7CT
    stm-2.4.4.1-iSYwp3RMY11sHCifJ3gtR
    stringsearch-0.3.6.6-8anNeXolBRk4a9DV14i2Be
    syb-0.6-IcoSwlPi2Nx4zSqMmorFPS text-1.2.2.2-3ENqlljngKa6xj1Go2fVWq
    time-1.6.0.1 transformers-0.5.2.0
    transformers-base-0.4.4-H3XecnBtTa65CX4xecxCVH
    transformers-compat-0.5.1.4-IuFogs8HAVUJBWVNMhtssu
    unordered-containers-0.2.8.0-1tqMF698WJE3INvmpuzQZc
    utf8-string-1.0.1.1-1DpjxLeTvGg7ttZZojxJR5
    vector-0.12.0.1-692PQMDMB6pIQ1uGwefDcQ
haddock-interfaces: /usr/share/doc/purescript/html/purescript.haddock
haddock-html: /usr/share/doc/purescript/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
